@@ -1,7 +1,7 @@
 import random
 from time import sleep
 
-from .core import *
+from python_redis_orm.core import *
 
 
 def generate_token(chars_count):
